@@ -2,7 +2,7 @@
 #include "kmerslib.h"
 #include <string>
 static PyObject* kmerslib_core_makeFFPS(PyObject *self, PyObject *args){
-	std::string dir;
+	const char *dir;
     int startk;
     int endk;
     int ndevice;
